import axios, { AxiosResponse, AxiosRequestConfig, Axios, AxiosError, InternalAxiosRequestConfig } from 'axios'
import { ResultEnum } from '@/enums/httpEnum'
import { getLocalStorage } from '@/utils'
export interface MyResponseType<T> {
  code: ResultEnum
  data: T
  message: string
}

export interface MyRequestInstance extends Axios {
  <T = any>(config: AxiosRequestConfig): Promise<MyResponseType<T>>
}

const axiosInstance = axios.create({
  baseURL: import.meta.env.VITE_DEV_PATH,
  timeout: 3000,
}) as unknown as MyRequestInstance

axiosInstance.interceptors.request.use(
  async (config: InternalAxiosRequestConfig) => {
    const tokenName = getLocalStorage('tokenName')
    const tokenValue = getLocalStorage('tokenValue')
    config.headers[tokenName] = tokenValue
    // config.headers['Authorization'] = 'Bearer ' + token
    return config
  },
  (err: AxiosError) => {
    Promise.reject(err)
  }
)

axiosInstance.interceptors.response.use(
  (res: AxiosResponse) => {
    return Promise.resolve(res.data)
  },
  async (err: AxiosError) => {
    // 如果不是401错误或者已经重试过，则直接返回错误
    return Promise.reject(err)
  }
)

export default axiosInstance
