import type { App } from "vue";
import { createRouter, createWebHashHistory, RouteRecordRaw } from "vue-router";
import LoginPage from "@/login/index";
import LayoutPage from "@/layout/index";
import modules from "@/router/modules";
import { useDictStore } from '@/store/modules/useDictStore/index';

const FreeRoutes: Array<RouteRecordRaw> = [
  {
    path: "/login",
    name: "Login",
    component: LoginPage,
    meta: {
      title: "Login",
    }
  },
];

const RootRoute: Array<RouteRecordRaw> = [
  {
    path: "/",
    name: "Home",
    component: LayoutPage,
    redirect: "/dashboard",
    children: [...modules.mainRoutes],
    beforeEnter: async (_to, _from, next) => {
      try {
        const dictStore = useDictStore();
        await dictStore.fetchDictData(); // 等待字典数据加载完成
        next(); // 数据加载成功后，继续路由导航
      } catch (error) {
        console.error('字典数据加载失败:', error);
        next(false); // 加载失败，取消导航
      }
    },
  },
];

export const constantRouter: Array<RouteRecordRaw> = [
  ...FreeRoutes,
  ...RootRoute,
];

const router = createRouter({
  history: createWebHashHistory(""),
  routes: constantRouter,
  strict: true,
});

export function setupRouter(app: App) {
  app.use(router);
}
export default router;
