import { RouteRecordRaw } from "vue-router";

// 引入路径
const importPath = {
  dashboard: () => import("@/views/dashboard/index"),
  trademarkManage: () => import("@/views/ip/trademark-management/manage/index"),
  patentDomestic: () => import("@/views/ip/patent-management/domestic/index"),
  patentForeign: () => import("@/views/ip/patent-management/foreign/index"),
  patentProtection: () =>
    import("@/views/ip/patent-management/protection/index"),
  patentOperate: () => import("@/views/ip/patent-management/operate/index"),
  articleDisplay: () => import("@/views/ap/article-display/index"),
  innovationNeeds: () => import("@/views/sti/innovation-needs/index"),
  technologyTransfer: () => import("@/views/sti/technology-transfer/index"),
  trademarkRenewal: () =>
    import("@/views/ip/trademark-management/renewal/index"),
  trademarkAmendment: () =>
    import("@/views/ip/trademark-management/amendment/index"),
  trademarkCancellation: () =>
    import("@/views/ip/trademark-management/cancellation/index"),
  trademarkOpposition: () =>
    import("@/views/ip/trademark-management/opposition/index"),
  trademarkRejection: () =>
    import("@/views/ip/trademark-management/rejection/index"),
};

const mainRoutes: Array<RouteRecordRaw> = [
  {
    path: "/dashboard",
    name: "dashboard",
    component: importPath["dashboard"],
    meta: {
      title: "工作台",
    },
  },
  {
    path: "/ip/trademark-management",
    name: "trademarkManagement",
    redirect: { name: "trademarkManage" },
    meta: {
      title: "商标管理",
    },
    children: [
      {
        path: "manage",
        name: "trademarkManage",
        component: importPath["trademarkManage"],
        meta: {
          title: "国内外商标管理",
        },
      },
      {
        path: "renewal",
        name: "trademarkRenewal",
        component: importPath["trademarkRenewal"],
        meta: {
          title: "商标续展",
        },
      },
      {
        path: "amendment",
        name: "trademarkAmendment",
        component: importPath["trademarkAmendment"],
        meta: {
          title: "商标变更",
        },
      },
      {
        path: "cancellation",
        name: "trademarkCancellation",
        component: importPath["trademarkCancellation"],
        meta: {
          title: "商标撤三",
        },
      },
      {
        path: "opposition",
        name: "trademarkOpposition",
        component: importPath["trademarkOpposition"],
        meta: {
          title: "商标异议/无效",
        },
      },
      {
        path: "rejection",
        name: "trademarkRejection",
        component: importPath["trademarkRejection"],
        meta: {
          title: "商标驳回复审",
        },
      },
    ],
  },
  {
    path: "/ip/patent-management",
    name: "patentManagement",
    redirect: { name: "patentDomestic" },
    meta: {
      title: "专利管理",
    },
    children: [
      {
        path: "domestic",
        name: "patentDomestic",
        component: importPath["patentDomestic"],
        meta: {
          title: "国内专利申请",
        },
      },
      {
        path: "foreign",
        name: "patentForeign",
        component: importPath["patentForeign"],
        meta: {
          title: "国外专利申请",
        },
      },
      {
        path: "protection",
        name: "patentProtection",
        component: importPath["patentProtection"],
        meta: {
          title: "专利维权咨询",
        },
      },
      {
        path: "operate",
        name: "patentOperate",
        component: importPath["patentOperate"],
        meta: {
          title: "专利运营需求",
        },
      },
    ],
  },
  {
    path: "/ap/article-display",
    name: "articleDisplay",
    meta: {
      title: "学术文章",
    },
    component: importPath["articleDisplay"],
  },
  {
    path: "/sti/innovation-needs",
    name: "innovationNeeds",
    meta: {
      title: "技术创新需求",
    },
    component: importPath["innovationNeeds"],
  },
  {
    path: "/sti/technology-transfer",
    name: "technologyTransfer",
    meta: {
      title: "技术成果转化",
    },
    component: importPath["technologyTransfer"],
  },
];

export default mainRoutes;
