import { defineStore } from "pinia";
import { ref } from "vue";
import { postDictBatch } from "@/api"; // 确保你有这个 API 方法

export const useDictStore = defineStore('dict', () => {
  // 定义状态
  const dictData = ref<Record<string, Array<{ label: string; value: string }>>>({});
  const loading = ref<boolean>(false);
  const error = ref<string | null>(null);

  // 定义获取数据的方法
  const fetchDictData = async () => {
    loading.value = true; // 设置加载状态
    error.value = null; // 清除之前的错误

    const data = {
      categories: [
        "applicant_type", 
        "trademark_renewal_is_changed", 
        "priority_review_status",
        "sex",
        "legal_status",
        "trademark_icon_is_changed",
        "trademark_classification",
        "drawing_type",
        "annual_fee_payment_status",
        "logo_legislation_type",
        "index_new_push_type",
        "is_draft",
        "mode_of_cooperation",
        "patents_type",
        "operation_status",
        "is_top",
        "achievement_evaluation_level",
        "internal_patent_application_progress",
        "applicant_needs",
        "expedite_status",
        "transfer_way",
        "country",
        "region",
        "tech_maturity",
        "review_status",
        "requirement_type"
      ],
    };

    try {
      const response = await postDictBatch(data) as unknown as any;

      if (response.code === 200) {
        dictData.value = response.data; // 存储整个字典数据
        console.log('dictData ==>', dictData.value);
      } else {
        error.value = `Error: ${response.message}`; // 处理非200状态
      }
    } catch (err: any) {
      error.value = `请求失败: ${err.message}`; // 处理请求错误
    } finally {
      loading.value = false; // 清除加载状态
    }
  };

  return {
    dictData,
    loading,
    error,
    fetchDictData,
  };
});
