import { ref, reactive, onMounted } from "vue";
import { useDictStore } from "@/store/modules/useDictStore/index";
import { getList, deleteProject } from "./useAxios.hook";
import { ElMessage, ElMessageBox } from "element-plus";

// 数据初始化
export const useDataListInit = () => {
  const dictStore = useDictStore();

  // 表单相关
  const formInline = reactive({
    patentsName: "", // 专利名称
    applicationNumber: "", // 申请号
    applicationDate: "", // 申请日
    authorizationDate: "", // 授权日
    patentHolder: "", // 专利权人
    inventor: "", // 发明人
    patentType: "", // 专利类型
    internalCaseNumber: "", // 内部案号
    patentProgress: "", // 专利进度
    technicalContact: "", // 技术对接人
    officialDeadline: "", // 审意官方绝限期
    legalStatus: "", // 法律状态
    annualFeePayment: "", // 年费缴纳
    priorityReview: "", // 优先审查
    agent: "", // 代理机构
    involvedTechnologyRoute: "", // 涉及技术路线
    projectNumber: "", // 研发立项序号
  });

  const updateInfo = ref();

  // 控制器
  const isCollapse = ref(true);
  const fieldVisible = ref(false);
  const createVisible = ref(false);
  const updateVisible = ref(false);

  // 表格相关
  const currentPage = ref(1);
  const pageSize = ref(10);
  const totalItems = ref(0);
  const tableData = ref([]);
  // 定义所有字段的配置项
  const fieldsConfig = ref([
    { key: "patentsName", label: "专利名称", visible: true }, // 专利名称
    { key: "applicationNumber", label: "申请号", visible: true }, // 申请号
    { key: "applicationDate", label: "申请日", visible: true }, // 申请日
    { key: "internalCaseNumber", label: "内部案号", visible: false }, // 内部案号
    { key: "technologyName", label: "技术对接人", visible: false }, // 技术对接人
    { key: "auditOfOfficialDeadlines", label: "审意官方绝限期", visible: false }, // 审意官方绝限期
    { key: "patentee", label: "专利权人", visible: false }, // 专利权人
    { key: "firstDeviseName", label: "发明人", visible: false }, // 发明人
    { key: "patentType", label: "专利类型", visible: false }, // 专利类型
    { key: "patentStatus", label: "专利进度", visible: true }, // 专利进度
    { key: "legislationStatus", label: "法律状态", visible: false }, // 法律状态
    { key: "paymentStatus", label: "年费缴纳", visible: false }, // 年费缴纳
    { key: "priorityReview", label: "优先审查", visible: false }, // 优先审查
    { key: "agency", label: "代理机构", visible: false }, // 代理机构
    { key: "involvingTechnicalRoutes", label: "涉及技术路线", visible: false }, // 涉及技术路线
    { key: "logs", label: "日志", visible: false }, // 日志
    { key: "expediteStatus", label: "是否加速", visible: true }, // 专利备注
    { key: "country", label: "进入国家", visible: true }, // 国家
    { key: "patentRemarks", label: "专利备注", visible: true }, // 专利备注
    // 可根据需要添加更多字段
  ]);

  const tempFieldsConfig = ref(JSON.parse(JSON.stringify(fieldsConfig.value)));
  const visibleFields = ref(
    fieldsConfig.value
      .filter((field) => field.visible)
      .map((field) => field.key)
  );

  // 配置
  const formLabelWidth = "120px";

  // 字典
  const patentsType = dictStore.dictData.patents_type;
  const legalStatus = dictStore.dictData.legal_status;
  const expediteStatus = dictStore.dictData.expedite_status;
  const ipap = dictStore.dictData.internal_patent_application_progress;

  const formFields = [
    {
      label: "专利名称",
      model: "patentsName",
      component: "el-input",
      attrs: {
        clearable: true,
        style: "width: 220px",
        placeholder: "请输入专利名称",
      },
    },
    {
      label: "申请号",
      model: "applicationNumber",
      component: "el-input",
      attrs: {
        clearable: true,
        style: "width: 220px",
        placeholder: "请输入申请号",
      },
    },
    {
      label: "申请日",
      model: "applicationDate",
      component: "el-date-picker",
      attrs: {
        type: "date",
        clearable: true,
        style: "width: 220px",
        placeholder: "选择申请日",
      },
    },
    {
      label: "授权日",
      model: "authorizationDate",
      component: "el-date-picker",
      attrs: {
        type: "date",
        clearable: true,
        style: "width: 220px",
        placeholder: "选择授权日",
      },
    },
    {
      label: "专利权人",
      model: "patentHolder",
      component: "el-input",
      attrs: {
        clearable: true,
        style: "width: 220px",
        placeholder: "请输入专利权人",
      },
    },
    {
      label: "发明人",
      model: "inventor",
      component: "el-input",
      attrs: {
        clearable: true,
        style: "width: 220px",
        placeholder: "请输入发明人",
      },
    },
    {
      label: "专利类型",
      model: "patentType",
      component: "el-select",
      attrs: {
        placeholder: "选择专利类型",
        clearable: true,
        style: "width: 220px",
      },
      options: patentsType, // 需要定义可选项
    },
    {
      label: "内部案号",
      model: "internalCaseNumber",
      component: "el-input",
      attrs: {
        clearable: true,
        style: "width: 220px",
        placeholder: "请输入内部案号",
      },
    },
    {
      label: "专利进度",
      model: "patentProgress",
      component: "el-select",
      attrs: {
        placeholder: "选择专利进度",
        clearable: true,
        style: "width: 220px",
      },
      options: ipap, // 需要定义可选项
    },
    {
      label: "技术对接人",
      model: "technicalContact",
      component: "el-input",
      attrs: {
        clearable: true,
        style: "width: 220px",
        placeholder: "请输入技术对接人",
      },
    },
    {
      label: "审意官方绝限期",
      model: "officialDeadline",
      component: "el-date-picker",
      attrs: {
        type: "date",
        clearable: true,
        style: "width: 220px",
        placeholder: "选择审意官方绝限期",
      },
    },
    {
      label: "法律状态",
      model: "legalStatus",
      component: "el-select",
      attrs: {
        placeholder: "选择法律状态",
        clearable: true,
        style: "width: 220px",
      },
      options: legalStatus, // 需要定义可选项
    },
    {
      label: "年费缴纳",
      model: "annualFeePayment",
      component: "el-date-picker",
      attrs: {
        type: "date",
        clearable: true,
        style: "width: 220px",
        placeholder: "选择年费缴纳日期",
      },
    },
    {
      label: "是否加速",
      model: "expediteStatus",
      component: "el-select",
      attrs: {
        placeholder: "请选择",
        clearable: true,
        style: "width: 220px",
      },
      options: expediteStatus, // 需要定义可选项
    },
    {
      label: "代理机构",
      model: "agent",
      component: "el-input",
      attrs: {
        clearable: true,
        style: "width: 220px",
        placeholder: "请输入代理机构",
      },
    },
    {
      label: "涉及技术路线",
      model: "involvedTechnologyRoute",
      component: "el-input",
      attrs: {
        clearable: true,
        style: "width: 220px",
        placeholder: "请输入涉及技术路线",
      },
    },
    {
      label: "研发立项序号",
      model: "projectNumber",
      component: "el-input",
      attrs: {
        clearable: true,
        style: "width: 220px",
        placeholder: "请输入研发立项序号",
      },
    },
  ];

  const fetchList = async () => {
    const data = {
      pageNumber: currentPage.value,
      pageSize: pageSize.value,
      ...formInline,
    };
    const res = (await getList(data)) as unknown as any;
    if (res.code === 200) {
      tableData.value = res.data.list;
    }
  };

  const onClickReset = () => {
    // 重置表单字段
    formInline.patentsName = "";
    formInline.applicationNumber = "";
    formInline.applicationDate = "";
    formInline.authorizationDate = "";
    formInline.patentHolder = "";
    formInline.inventor = "";
    formInline.patentType = "";
    formInline.internalCaseNumber = "";
    formInline.patentProgress = "";
    formInline.technicalContact = "";
    formInline.officialDeadline = "";
    formInline.legalStatus = "";
    formInline.annualFeePayment = "";
    formInline.priorityReview = ""; // 优先审查重置为 false
    formInline.agent = "";
    formInline.involvedTechnologyRoute = "";
    formInline.projectNumber = "";

    // 重置分页
    currentPage.value = 1; // 或者您设定的其他默认页码
    pageSize.value = 10; // 或者您设定的其他默认每页数量

    // 调用 fetchList 以获取重置后的数据
    fetchList();
  };

  const onCollapse = () => {
    isCollapse.value = !isCollapse.value;
  };

  const handleCurrentChange = (val: number) => {
    currentPage.value = val;
    fetchList();
  };

  const onUpdate = (row: any) => {
    updateInfo.value = row;
    updateVisible.value = true;
  };

  const onFieldChange = (newTargetKeys: string | string[]) => {
    // 更新临时字段配置
    tempFieldsConfig.value.forEach(
      (field: { visible: boolean; key: string }) => {
        field.visible = newTargetKeys.includes(field.key);
      }
    );
  };

  const saveFieldSettings = () => {
    fieldsConfig.value.forEach((field, index) => {
      field.visible = tempFieldsConfig.value[index].visible;
    });

    // 更新可见字段列表
    visibleFields.value = fieldsConfig.value
      .filter((field) => field.visible)
      .map((field) => field.key);

    fieldVisible.value = false;
    // 可在此处将 visibility 的设置保存到后端
  };

  const handleCreate = () => {
    createVisible.value = false;
    fetchList();
  };

  // 执行删除专利，记得加提示
  const onDelete = (row: any) => {
    ElMessageBox.confirm(
      "请确认要删除专利名称为【" + row.patentsName + "】的专利信息",
      "提示信息",
      {
        confirmButtonText: "确认",
        cancelButtonText: "取消",
        type: "warning",
      }
    )
      .then(async () => {
        const res = (await deleteProject(row.id)) as unknown as any;
        if (res.code === 200) {
          ElMessage({
            type: "success",
            message: "删除成功",
          });
          fetchList();
        } else {
          ElMessage({
            type: "error",
            message: "删除失败，请联系管理员",
          });
        }
      })
      .catch(() => {
        ElMessage({
          type: "info",
          message: "取消删除",
        });
      });
  };

  onMounted(() => {
    fetchList();
  });

  return {
    formInline,
    updateInfo,
    isCollapse,
    fieldVisible,
    createVisible,
    updateVisible,
    currentPage,
    pageSize,
    totalItems,
    tableData,
    visibleFields,
    fieldsConfig,
    formLabelWidth,
    formFields,
    fetchList,
    onClickReset,
    onCollapse,
    handleCurrentChange,
    onUpdate,
    onFieldChange,
    saveFieldSettings,
    handleCreate,
    onDelete,
  };
};
