import { ref, onMounted } from "vue";
import { getList, deleteProject } from "./useAxios.hook";
import { ElMessage, ElMessageBox } from "element-plus";

// 数据初始化
export const useDataListInit = () => {
  // 表格相关
  const currentPage = ref(1);
  const pageSize = ref(10);
  const totalItems = ref(0);
  const tableData = ref([]);

  const fieldsConfig = ref([
    { key: "userName", label: "用户名称", visible: true, width: "200" },
    { key: "contactDetails", label: "联系方式", visible: true, width: "300" },
    { key: "patentNumber", label: "专利号", visible: true, width: "200" },
    { key: "createTime", label: "咨询日期", visible: true, width: "200" },
    { key: "description", label: "问题描述", visible: true,  },
  ]);

  // 获取数据列表
  const fetchList = async () => {
    const data = {
      pageNumber: currentPage.value,
      pageSize: pageSize.value,
    };
    const res = (await getList(data)) as any;
    if (res.code === 200) {
      tableData.value = res.data.list;
      totalItems.value = res.data.total; // 假设返回的数据中有 total 字段
    }
  };

  // 页面切换
  const handleCurrentChange = (val: number) => {
    currentPage.value = val;
    fetchList();
  };

  // 删除操作
  const onDelete = (row: any) => {
    ElMessageBox.confirm(
      `请确认要删除用户名为【${row.userName}】的专利维权咨询`,
      "提示信息",
      {
        confirmButtonText: "确认",
        cancelButtonText: "取消",
        type: "warning",
      }
    )
      .then(async () => {
        const res = (await deleteProject(row.id)) as any;
        if (res.code === 200) {
          ElMessage({
            type: "success",
            message: "删除成功",
          });
          fetchList();
        } else {
          ElMessage({
            type: "error",
            message: "删除失败，请联系管理员",
          });
        }
      })
      .catch(() => {
        ElMessage({
          type: "info",
          message: "取消删除",
        });
      });
  };

  onMounted(() => {
    fetchList();
  });

  return {
    currentPage,
    pageSize,
    totalItems,
    tableData,
    fieldsConfig,
    handleCurrentChange,
    onDelete,
  };
};
