import { ref, reactive, onMounted } from "vue";
import { useDictStore } from "@/store/modules/useDictStore/index";
import { getList, deleteProject } from "./useAxios.hook";
import { ElMessage, ElMessageBox } from "element-plus";

// 数据初始化
export const useDataListInit = () => {
  const dictStore = useDictStore();

  // 表单相关
  const formInline = reactive({
    trademarkName: "",
    logoNumber: "",
    applicationDate: "",
    firstInstanceDate: "",
    enrollmentDate: "",
    exclusiveRightsAsOf: "",
    rightHolder: "",
    country: "",
    dateOfDismissal: "",
    agent: "",
    trademarkCategorization: "",
    legalStatus: "",
  });

  const updateInfo = ref();

  // 控制器
  const isCollapse = ref(true);
  const fieldVisible = ref(false);
  const createVisible = ref(false);
  const updateVisible = ref(false);

  // 表格相关
  const currentPage = ref(1);
  const pageSize = ref(10);
  const totalItems = ref(0);
  const tableData = ref([]);
  // 定义所有字段的配置项
  const fieldsConfig = ref([
    { key: "trademarkName", label: "商标名称", visible: true },
    { key: "trademarkCategorization", label: "类别", visible: true },
    { key: "logoNumber", label: "商标号", visible: true },
    { key: "applicationDate", label: "申请日期", visible: true },
    { key: "legalStatus", label: "法律状态", visible: true },
    { key: "enrollmentDate", label: "注册公告日", visible: true },
    { key: "exclusiveRightsAsOf", label: "专有权截止日", visible: true },
    { key: "country", label: "国家地区", visible: false },
    { key: "cluster", label: "群组", visible: false },
    { key: "agent", label: "代理机构", visible: false },
    { key: "dateOfDismissal", label: "驳回发文日", visible: false },
    { key: "userId", label: "用户ID", visible: false },
    { key: "rightHolder", label: "权利人", visible: false },
    { key: "firstInstanceDate", label: "初始公告日", visible: false },
    { key: "deadlineForDismissal", label: "驳回截止日", visible: false },
    { key: "uncoveredGroups", label: "未覆盖群组", visible: false },
  ]);
  const tempFieldsConfig = ref(JSON.parse(JSON.stringify(fieldsConfig.value)));
  const visibleFields = ref(
    fieldsConfig.value
      .filter((field) => field.visible)
      .map((field) => field.key)
  );

  // 配置
  const formLabelWidth = "120px";

  // 字典
  const trademarkClassification = dictStore.dictData.trademark_classification;
  const logoLegislationType = dictStore.dictData.logo_legislation_type;

  // 动态表单字段配置
  const formFields = [
    {
      label: "商标名称",
      model: "trademarkName",
      component: "el-input",
      attrs: {
        clearable: true,
        style: "width: 220px",
        placeholder: "请输入商标名称",
      },
    },
    {
      label: "商标号",
      model: "logoNumber",
      component: "el-input",
      attrs: {
        clearable: true,
        style: "width: 220px",
        placeholder: "请输入商标号",
      },
    },
    {
      label: "申请日期",
      model: "applicationDate",
      component: "el-date-picker",
      attrs: {
        type: "date",
        clearable: true,
        style: "width: 220px",
        placeholder: "选择申请日期",
      },
    },
    {
      label: "初审公告日",
      model: "firstInstanceDate",
      component: "el-date-picker",
      attrs: {
        type: "date",
        clearable: true,
        style: "width: 220px",
        placeholder: "选择初审公告日",
      },
    },
    {
      label: "注册公告日",
      model: "enrollmentDate",
      component: "el-date-picker",
      attrs: {
        type: "date",
        clearable: true,
        style: "width: 220px",
        placeholder: "选择注册公告日",
      },
    },
    {
      label: "专有权截至日",
      model: "exclusiveRightsAsOf",
      component: "el-date-picker",
      attrs: {
        type: "date",
        clearable: true,
        style: "width: 220px",
        placeholder: "选择专有权截至日",
      },
    },
    {
      label: "权利人",
      model: "rightHolder",
      component: "el-input",
      attrs: {
        clearable: true,
        style: "width: 220px",
        placeholder: "请输入权利人",
      },
    },
    {
      label: "国家",
      model: "country",
      component: "el-input",
      attrs: {
        clearable: true,
        style: "width: 220px",
        placeholder: "请输入国家",
      },
    },
    {
      label: "驳回发文日",
      model: "dateOfDismissal",
      component: "el-date-picker",
      attrs: {
        type: "date",
        clearable: true,
        style: "width: 220px",
        placeholder: "选择驳回发文日",
      },
    },
    {
      label: "代理机构",
      model: "agent",
      component: "el-input",
      attrs: {
        clearable: true,
        style: "width: 220px",
        placeholder: "请输入代理机构",
      },
    },
    {
      label: "商标类别",
      model: "trademarkCategorization",
      component: "el-select",
      attrs: {
        placeholder: "选择商标类别",
        clearable: true,
        style: "width: 220px",
      },
      options: trademarkClassification,
    },
    {
      label: "法律状态",
      model: "legalStatus",
      component: "el-select",
      attrs: {
        placeholder: "选择法律状态",
        clearable: true,
        style: "width: 220px",
      },
      options: logoLegislationType,
    },
  ];

  const fetchList = async () => {
    const data = {
      pageNumber: currentPage.value,
      pageSize: pageSize.value,
      ...formInline,
    };
    const res = (await getList(data)) as unknown as any;
    if (res.code === 200) {
      tableData.value = res.data.list;
    }
  };

  const onClickReset = () => {
    // 重置表单字段
    formInline.trademarkName = "";
    formInline.logoNumber = "";
    formInline.applicationDate = "";
    formInline.firstInstanceDate = "";
    formInline.enrollmentDate = "";
    formInline.exclusiveRightsAsOf = "";
    formInline.rightHolder = "";
    formInline.country = "";
    formInline.dateOfDismissal = "";
    formInline.agent = "";

    // 如果有其他字段需要重置
    formInline.trademarkCategorization = "";
    formInline.legalStatus = "";

    // 重置分页
    currentPage.value = 1; // 或者你设定的其他默认页码
    pageSize.value = 10; // 或者你设定的其他默认每页数量

    // 调用 fetchList 以获取重置后的数据
    fetchList();
  };

  const onCollapse = () => {
    isCollapse.value = !isCollapse.value;
  };

  const handleCurrentChange = (val: number) => {
    currentPage.value = val;
    fetchList();
  };

  const onUpdate = (row: any) => {
    updateInfo.value = row;
    updateVisible.value = true;
  };

  const onFieldChange = (newTargetKeys: string | string[]) => {
    // 更新临时字段配置
    tempFieldsConfig.value.forEach(
      (field: { visible: boolean; key: string }) => {
        field.visible = newTargetKeys.includes(field.key);
      }
    );
  };

  const saveFieldSettings = () => {
    fieldsConfig.value.forEach((field, index) => {
      field.visible = tempFieldsConfig.value[index].visible;
    });

    // 更新可见字段列表
    visibleFields.value = fieldsConfig.value
      .filter((field) => field.visible)
      .map((field) => field.key);

    fieldVisible.value = false;
    // 可在此处将 visibility 的设置保存到后端
  };

  const handleCreate = () => {
    createVisible.value = false;
    fetchList();
  };

  // 执行删除商标，记得加提示
  const onDelete = (row: any) => {
    ElMessageBox.confirm(
      "请确认要删除商标名称为【" + row.trademarkName + "】的商标信息",
      "提示信息",
      {
        confirmButtonText: "确认",
        cancelButtonText: "取消",
        type: "warning",
      }
    )
      .then(async () => {
        const res = (await deleteProject(row.id)) as unknown as any;
        if (res.code === 200) {
          ElMessage({
            type: "success",
            message: "删除成功",
          });
          fetchList();
        } else {
          ElMessage({
            type: "error",
            message: "删除失败，请联系管理员",
          });
        }
      })
      .catch(() => {
        ElMessage({
          type: "info",
          message: "取消删除",
        });
      });
  };

  onMounted(() => {
    fetchList();
  });

  return {
    formInline,
    updateInfo,
    isCollapse,
    fieldVisible,
    createVisible,
    updateVisible,
    currentPage,
    pageSize,
    totalItems,
    tableData,
    visibleFields,
    fieldsConfig,
    formLabelWidth,
    formFields,
    fetchList,
    onClickReset,
    onCollapse,
    handleCurrentChange,
    onUpdate,
    onFieldChange,
    saveFieldSettings,
    handleCreate,
    onDelete,
  };
};
