import { ref, reactive, onMounted } from "vue";
import { getList, deleteProject } from "./useAxios.hook";
import { ElMessage, ElMessageBox } from "element-plus";

// 数据初始化
export const useDataListInit = () => {
  // 表单相关
  const formInline = reactive({
    logoRegistrationNumber: "",
  });

  const updateInfo = ref();

  // 控制器
  const isCollapse = ref(true);
  const fieldVisible = ref(false);
  const createVisible = ref(false);
  const updateVisible = ref(false);

  // 表格相关
  const currentPage = ref(1);
  const pageSize = ref(10);
  const totalItems = ref(0);
  const tableData = ref([]);
  // 定义所有字段的配置项
  const fieldsConfig = ref([
    { key: "logoRegistrationNumber", label: "注册号", visible: true },
    { key: "createTime", label: "类别", visible: true },
    { key: "applicant", label: "申请人", visible: true },
    { key: "country", label: "国家", visible: true },
    { key: "contactDetails", label: "联系方式", visible: true },
    { key: "applicantAddr", label: "地址", visible: true },
  ]);
  const tempFieldsConfig = ref(JSON.parse(JSON.stringify(fieldsConfig.value)));
  const visibleFields = ref(
    fieldsConfig.value
      .filter((field) => field.visible)
      .map((field) => field.key)
  );

  // 配置
  const formLabelWidth = "120px";

  // 动态表单字段配置
  const formFields = [
    {
      label: "商标注册号",
      model: "logoRegistrationNumber",
      component: "el-input",
      attrs: {
        clearable: true,
        style: "width: 220px",
        placeholder: "请输入商标注册号",
      },
    },
  ];

  const fetchList = async () => {
    const data = {
      pageNumber: currentPage.value,
      pageSize: pageSize.value,
      ...formInline,
    };
    const res = (await getList(data)) as unknown as any;
    if (res.code === 200) {
      tableData.value = res.data.list;
    }
  };

  const onClickReset = () => {
    // 重置表单字段
    formInline.logoRegistrationNumber = "";

    // 重置分页
    currentPage.value = 1; // 或者你设定的其他默认页码
    pageSize.value = 10; // 或者你设定的其他默认每页数量

    // 调用 fetchList 以获取重置后的数据
    fetchList();
  };

  const onCollapse = () => {
    isCollapse.value = !isCollapse.value;
  };

  const handleCurrentChange = (val: number) => {
    currentPage.value = val;
    fetchList();
  };

  const onUpdate = (row: any) => {
    updateInfo.value = row;
    updateVisible.value = true;
  };

  const onFieldChange = (newTargetKeys: string | string[]) => {
    // 更新临时字段配置
    tempFieldsConfig.value.forEach(
      (field: { visible: boolean; key: string }) => {
        field.visible = newTargetKeys.includes(field.key);
      }
    );
  };

  const saveFieldSettings = () => {
    fieldsConfig.value.forEach((field, index) => {
      field.visible = tempFieldsConfig.value[index].visible;
    });

    // 更新可见字段列表
    visibleFields.value = fieldsConfig.value
      .filter((field) => field.visible)
      .map((field) => field.key);

    fieldVisible.value = false;
    // 可在此处将 visibility 的设置保存到后端
  };

  const handleCreate = () => {
    createVisible.value = false;
    fetchList();
  };

  // 执行删除商标，记得加提示
  const onDelete = (row: any) => {
    ElMessageBox.confirm(
      "请确认要删除商标名称为【" + row.trademarkName + "】的商标信息",
      "提示信息",
      {
        confirmButtonText: "确认",
        cancelButtonText: "取消",
        type: "warning",
      }
    )
      .then(async () => {
        const res = (await deleteProject(row.id)) as unknown as any;
        if (res.code === 200) {
          ElMessage({
            type: "success",
            message: "删除成功",
          });
          fetchList();
        } else {
          ElMessage({
            type: "error",
            message: "删除失败，请联系管理员",
          });
        }
      })
      .catch(() => {
        ElMessage({
          type: "info",
          message: "取消删除",
        });
      });
  };

  onMounted(() => {
    fetchList();
  });

  return {
    formInline,
    updateInfo,
    isCollapse,
    fieldVisible,
    createVisible,
    updateVisible,
    currentPage,
    pageSize,
    totalItems,
    tableData,
    visibleFields,
    fieldsConfig,
    formLabelWidth,
    formFields,
    fetchList,
    onClickReset,
    onCollapse,
    handleCurrentChange,
    onUpdate,
    onFieldChange,
    saveFieldSettings,
    handleCreate,
    onDelete,
  };
};
