import { ref, reactive, onMounted } from "vue";
import { useDictStore } from "@/store/modules/useDictStore/index";
import { getList, postUpdate, deleteProject } from "./useAxios.hook";
import { ElMessage, ElMessageBox } from "element-plus";

// 数据初始化
export const useDataListInit = () => {
  const dictStore = useDictStore();

  // 表单相关
  const formInline = reactive({
    maturityLevel: "",
    conveyancing: "",
    isTransaction: "",
  });

  const updateInfo = ref();

  // 控制器
  const isCollapse = ref(true);
  const fieldVisible = ref(false);
  const createVisible = ref(false);
  const updateVisible = ref(false);

  // 表格相关
  const currentPage = ref(1);
  const pageSize = ref(10);
  const totalItems = ref(0);
  const tableData = ref([]);
  // 定义所有字段的配置项
  const fieldsConfig = ref([
    { key: "technologicalNeedsName", label: "成果名称", visible: true },
    { key: "createTime", label: "申请日", visible: true },
    { key: "patentAssociations", label: "关联成果", visible: true },
    { key: "maturityLevel", label: "成熟度", visible: true },
    { key: "conveyancing", label: "转让方式", visible: true },
    { key: "isTransaction", label: "是否成交", visible: true },
    { key: "contactNumber", label: "联系电话", visible: true },
    { key: "auditStatus", label: "审核状态", visible: true },
  ]);

  const tempFieldsConfig = ref(JSON.parse(JSON.stringify(fieldsConfig.value)));
  const visibleFields = ref(
    fieldsConfig.value
      .filter((field) => field.visible)
      .map((field) => field.key)
  );

  // 配置
  const formLabelWidth = "120px";

  // 字典
  const is_top = dictStore.dictData.is_top;
  const transfer_way = dictStore.dictData.transfer_way;

  const formFields = [
    {
      label: "成熟度",
      model: "maturityLevel",
      component: "el-input",
      attrs: {
        clearable: true,
        style: "width: 220px",
        placeholder: "请输入成熟度",
      },
    },
    {
      label: "转让方式",
      model: "conveyancing",
      component: "el-select",
      attrs: {
        placeholder: "选择",
        clearable: true,
        style: "width: 220px",
      },
      options: transfer_way, // 需要定义可选项
    },
    {
      label: "是否成交",
      model: "isTransaction",
      component: "el-select",
      attrs: {
        placeholder: "选择",
        clearable: true,
        style: "width: 220px",
      },
      options: is_top, // 需要定义可选项
    },
  ];

  const fetchList = async () => {
    const data = {
      pageNumber: currentPage.value,
      pageSize: pageSize.value,
      ...formInline,
    };
    const res = (await getList(data)) as unknown as any;
    if (res.code === 200) {
      tableData.value = res.data.list;
    }
  };

  const onClickReset = () => {
    formInline.maturityLevel = "",
    formInline.conveyancing = "",
    formInline.isTransaction = "",

    // 重置分页
    currentPage.value = 1; // 或者您设定的其他默认页码
    pageSize.value = 10; // 或者您设定的其他默认每页数量

    // 调用 fetchList 以获取重置后的数据
    fetchList();
  };

  const onCollapse = () => {
    isCollapse.value = !isCollapse.value;
  };

  const handleCurrentChange = (val: number) => {
    currentPage.value = val;
    fetchList();
  };

  const onUpdate = async (row: any, isExamine: boolean) => {
    if (isExamine) {
      ElMessageBox.confirm(
        "请确认要通过名称为【" + row.technologicalNeedsName + "】的审核批准",
        "提示信息",
        {
          confirmButtonText: "通过",
          cancelButtonText: "取消",
          type: "warning",
        }
      )
        .then(async () => {
          const data = {
            id: row.id,
            auditStatus: "1",
          };
          const res = (await postUpdate(data)) as unknown as any;
          if (res.code === 200) {
            ElMessage({
              type: "success",
              message: "操作成功",
            });
            fetchList();
          } else {
            ElMessage({
              type: "error",
              message: "操作失败，请联系管理员",
            });
          }
        })
        .catch(() => {
          ElMessage({
            type: "info",
            message: "取消删除",
          });
        });
    } else {
      const data = {
        id: row.id,
        auditStatus: "0",
      };
      const res = (await postUpdate(data)) as unknown as any;
      if (res.code === 200) {
        ElMessage({
          type: "success",
          message: "操作成功",
        });
        fetchList();
      } else {
        ElMessage({
          type: "error",
          message: "操作失败，请联系管理员",
        });
      }
    }
  };

  const onFieldChange = (newTargetKeys: string | string[]) => {
    // 更新临时字段配置
    tempFieldsConfig.value.forEach(
      (field: { visible: boolean; key: string }) => {
        field.visible = newTargetKeys.includes(field.key);
      }
    );
  };

  const saveFieldSettings = () => {
    fieldsConfig.value.forEach((field, index) => {
      field.visible = tempFieldsConfig.value[index].visible;
    });

    // 更新可见字段列表
    visibleFields.value = fieldsConfig.value
      .filter((field) => field.visible)
      .map((field) => field.key);

    fieldVisible.value = false;
    // 可在此处将 visibility 的设置保存到后端
  };

  const handleCreate = () => {
    createVisible.value = false;
    fetchList();
  };

  // 执行删除专利，记得加提示
  const onDelete = (row: any) => {
    ElMessageBox.confirm(
      "请确认要删除专利名称为【" + row.patentsName + "】的专利信息",
      "提示信息",
      {
        confirmButtonText: "确认",
        cancelButtonText: "取消",
        type: "warning",
      }
    )
      .then(async () => {
        const res = (await deleteProject(row.id)) as unknown as any;
        if (res.code === 200) {
          ElMessage({
            type: "success",
            message: "删除成功",
          });
          fetchList();
        } else {
          ElMessage({
            type: "error",
            message: "删除失败，请联系管理员",
          });
        }
      })
      .catch(() => {
        ElMessage({
          type: "info",
          message: "取消删除",
        });
      });
  };

  onMounted(() => {
    fetchList();
  });

  return {
    formInline,
    updateInfo,
    isCollapse,
    fieldVisible,
    createVisible,
    updateVisible,
    currentPage,
    pageSize,
    totalItems,
    tableData,
    visibleFields,
    fieldsConfig,
    formLabelWidth,
    formFields,
    fetchList,
    onClickReset,
    onCollapse,
    handleCurrentChange,
    onUpdate,
    onFieldChange,
    saveFieldSettings,
    handleCreate,
    onDelete,
  };
};
